<?php

class rdc_store extends hook
{
	public $hookName = "rdc_store";
	public $active = true;			//enable/disable hook (true => enabled)
	public $timer = 0;
	public $luminance_min = 60;
	public $luminance_max = 3000;
	public $storeDownTime = 38;
	public $storeUpTime = 41;
	public $maxLevel;
	protected $storeLevel;
	protected $propertyInitialized =array();
	protected $devicelist = array(
		RDC_EXTERIEUR_LUMINOSITE => "illuminance_lux",
		METEO => "rainin",
		//METEO => "solarradiation",
		METEO => "windspeedkmh",
		METEO => "windgustkmh"
	);

	// callback fonction. Is called with these 3 parameters
	// $device 		-> calling device
	// $property 	-> property of the device (given by mqtt)
	// $value 		-> value of the property
	public function callBack($device, $property, $value)
	{
		global $mohaDB, $devices, $indexDevices;

		logger(DEBUG, "Callback : RDC_STORE", __FILE__ . ":" . __LINE__);
		$rain = 0;
		$exterieur_lux = 0;
		$salon_lux = 0;
		$rafale = 0;
		$soleil = 0;
		$storeDevice = $indexDevices[RDC_STORE];

		if (array_key_exists("position", $storeDevice->properties))
		{
			$this->storeLevel = 100 - $storeDevice->properties["position"]["value"];
			logger(DEBUG, "storeLevel=" . $this->storeLevel, __FILE__ . ":" . __LINE__);
		}else
		{
			$this->storeLevel = 0;
			//return true;
		}
		if (array_key_exists("illuminance_lux", $indexDevices[RDC_EXTERIEUR_LUMINOSITE]->properties))
		{
			$exterieur_lux = $mohaDB->moyenne($indexDevices[RDC_EXTERIEUR_LUMINOSITE], "illuminance_lux", 15);
			logger(DEBUG, "exterieur_lux=" . $exterieur_lux, __FILE__ . ":" . __LINE__);
		}
		if (array_key_exists("illuminance_lux", $indexDevices[RDC_SALON_LUMINOSITE]->properties))
		{
			$salon_lux = $mohaDB->moyenne($indexDevices[RDC_SALON_LUMINOSITE], "illuminance_lux", 10);
			logger(DEBUG, "salon_lux=" . $salon_lux, __FILE__ . ":" . __LINE__);
		}
		if (array_key_exists(METEO, $indexDevices))
		{
			if (array_key_exists("rainin", $indexDevices[METEO]->properties))
			{
				$rain = $indexDevices[METEO]->properties["rainin"]["value"];
				logger(DEBUG, "rain=" . var_dump($rain), __FILE__ . ":" . __LINE__);
			}
			if (array_key_exists("windgustkmh", $indexDevices[METEO]->properties))
			{
				$rafale = $mohaDB->moyenne($indexDevices[METEO], "windgustkmh", 12);
				logger(DEBUG, "rafale=" . $rafale, __FILE__ . ":" . __LINE__);
			}
			if (array_key_exists("solarradiation", $indexDevices[METEO]->properties))
			{
				$soleil = $mohaDB->moyenne($indexDevices[METEO], "solarradiation", 12);
				logger(DEBUG, "soleil=" . $exterieur_lux, __FILE__ . ":" . __LINE__);
			}
		}
		logger(DEBUG, sprintf(_("property=%s, value=%s"), $property, $value), __FILE__ . ":" . __LINE__);
		if ($rafale >= 60 or $rain != 0)
		{
			$this->maxLevel = 0;
			logger(DEBUG, sprintf("rafale = %s  and rain = %s",$rafale, $rain), __FILE__ . ":" . __LINE__);
			$this->close("vent trop fort ou pluie");
			return 0;
		}elseif ($rafale != 0)
		{
			$this->maxLevel = ($r = 100 - round(($rafale-10)/5, 0, PHP_ROUND_HALF_UP)*20)<0 ? 0 : $r;
			//$this->maxLevel = 100 / $rafale;
			logger(DEBUG, "rafale=" . $rafale, __FILE__ . ":" . __LINE__);
		}
		logger(DEBUG, "maxlevel=" . $this->maxLevel, __FILE__ . ":" . __LINE__);
		//$store2level = $this->maxLevel;
		switch ($property)
		{
		case "illuminance_lux":
			logger(DEBUG, "CASE: illuminance_lux:" . $value, __FILE__ . ":" . __LINE__);
			if ($exterieur_lux > 40000)
			{
				logger(DEBUG, "exterieur_lux > 40000", __FILE__ . ":" . __LINE__);
				if ($this->maxLevel != 0 and $salon_lux > 150)
				{
					$store2level = $this->storeLevel + 15;
					if ( $store2level > $this->maxLevel )
					{
						logger(DEBUG, "store2level > maxLevel", __FILE__ . ":" . __LINE__);
						$this->set($this->maxLevel);
					}else
					{
						logger(DEBUG, "store2level <= maxLevel", __FILE__ . ":" . __LINE__);
						$this->set($store2level);
					}
				}
			}elseif ($exterieur_lux < 35000)
			{
				logger(DEBUG, "exterieur_lux < 35000", __FILE__ . ":" . __LINE__);
				$this->close("Luminosité faible");
			}
			break;
		case "rainin":
			logger(DEBUG, "CASE: rainin:" . $value, __FILE__ . ":" . __LINE__);
			$this->close("Pluie");
			break;
		case "windgustkmh";
			logger(DEBUG, "CASE: windgustkmh:" . $rafale, __FILE__ . ":" . __LINE__);
		//case "windspeedkmh":
		//	logger(DEBUG, "CASE: windspeedkmh:" . $value, __FILE__ . ":" . __LINE__);

			logger(DEBUG, "maxLevel = " . $this->maxLevel . ' result => $r = ' . $r, __FILE__ . ":" . __LINE__);
			if ($this->storeLevel > $this->maxLevel)
			{
				$this->set($this->maxLevel);
			}
			break;
		default:
		}
		if ($store2level <= $this->storeLevel)
		{
			$this->set($store2level);
		}
	}

	private function set ($level)
	{
		if ($this->storeLevel < $level)
		{
			logger(DEBUG, "Open store :" . $level, __FILE__ . ":" . __LINE__);
			$this->send(100 - $level);
		}
	}

	private function close ($reason)
	{
		if ($this->storeLevel != 0)
		{
			logger(DEBUG, "Close store :" . $reason, __FILE__ . ":" . __LINE__);
			$this->send(100);
		}
	}

	private function send($level)
	{
		global $indexDevices;
		$deviceObject = $indexDevices[RDC_STORE];
		$msg = array("position" => $level);
		logger(INFO, sprintf(_("publishing message: %s to %s"), json_encode($msg), $deviceObject->friendlyName), __FILE__ . ":" . __LINE__);
		$deviceObject->payload = $msg;
		$deviceObject->set(AUTO);
	}
}

$hooks["rdc_store"] = new rdc_store();
?>
